@@ -998,7 +998,7 @@ def list_conf_files(type_co):
     dossier = dossier + type_co
     files = os.listdir(dossier)
     for file in files:
-        if file.lower().endswith(".json"):
+        if file.lower().endswith(".json") or file.lower().endswith(".sec") :
             conf_files.append(file)
     return conf_files
 
