@@ -2,7 +2,6 @@ import os
 import json
 import hashlib
 import getpass
-from cryptography.fernet import Fernet
 import base64
 
 if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
@@ -12,7 +11,14 @@ else:
     from orangecontrib.AAIT.utils import MetManagement
     from orangecontrib.IO4IT.utils import secret_manager
 
-
+def ask_secure():
+    while True:
+        resp = input("Secure? (Y/N) : ").strip().lower()
+        if resp in ("y", "yes"):
+            return True
+        if resp in ("n", "no"):
+            return False
+        print("Please enter Y or N.")
 #  FONCTIOSN D'OBFUSCATION GÉNÉRALES & CHEMIN
 # Fonction pour générer une clé simple à partir du nom d'utilisateur
 def get_user_key():
@@ -59,24 +65,8 @@ def get_keys_dir(type_key: str = "MICROSOFT_EXCHANGE_OAUTH2") -> str:
         raise RuntimeError(f"Erreur création/récupération dossier : {e}")
 
 
-def get_fernet_key() -> bytes:
-    """
-    Dérive une clé Fernet (32 octets base64) à partir du nom d'utilisateur local.
-    """
-    username = getpass.getuser().encode("utf-8")
-    digest = hashlib.sha256(username).digest()
-    return base64.urlsafe_b64encode(digest[:32])  # 32 bytes en base64
 
 
-def encrypt_secure(data: str) -> str:
-    fernet = Fernet(get_fernet_key())
-    return fernet.encrypt(data.encode("utf-8")).decode("utf-8")
-
-
-def decrypt_secure(data: str) -> str:
-    fernet = Fernet(get_fernet_key())
-    return fernet.decrypt(data.encode("utf-8")).decode("utf-8")
-
 
 # GSTION IMAP
 #je n'ai pas compris à quoi ça sert et ce n'est pas utilisé: à supprimer
@@ -181,88 +171,45 @@ def enregistrer_config_owa(mail, alias, server, username, password, interval):
         print(f"❌ Erreur lors de l'enregistrement : {e}")
         return 1
 
-
 def enregistrer_config_owa_secure(mail, alias, server, username, password, interval):
     try:
-        dossier = get_keys_dir("MICROSOFT_EXCHANGE_OWA_SECURE")
-        os.makedirs(dossier, exist_ok=True)
+        dossier = get_keys_dir("MICROSOFT_EXCHANGE_OWA")
+        # Crée le dossier s'il n'existe pas
+        if not os.path.exists(dossier):
+            os.makedirs(dossier)
 
-        mdp_chiffre = encrypt_secure(password)
+        # Récupère l'adresse MAC et chiffre le mot de passe
+        key = get_user_key()
+        mdp_chiffre = xor_crypt(password, key)
 
-        nom_fichier = os.path.join(dossier, f"{alias.replace('@', '_at_')}.json")
+        # Nom du fichier (remplace @ par _at_ pour éviter les problèmes)
+        nom_fichier = os.path.join(dossier, f"{alias.replace('@', '_at_')}.sec")
+        service_name=f"MICROSOFT_EXCHANGE_OWA__{alias.replace('@', '_at_')}"
 
+
+        # Contenu à écrire dans le fichier
         contenu = {
             "mail": mail,
             "alias": alias,
             "server": server,
             "username": username,
-            "password_encrypted": mdp_chiffre,
+            "password_encrypted": password,
             "interval_second": interval
         }
-
+        sm = secret_manager.SecretManager(service_name)
+        sm.store(contenu)
+        # Écriture du fichier
         with open(nom_fichier, "w", encoding="utf-8") as f:
-            json.dump(contenu, f, indent=4)
+            pass
 
-        print(f"✅ Fichier OWA sécurisé enregistré : {nom_fichier}")
+        print(f"✅ Fichier enregistré : {nom_fichier}")
         return 0
 
     except Exception as e:
-        print(f"❌ Erreur d'enregistrement sécurisé OWA : {e}")
+        print(f"❌ Erreur lors de l'enregistrement : {e}")
         return 1
 
 
-def enregistrer_config_cli_owa_secure():
-    print("\n🔐 Écriture fichier OWA avec chiffrement sécurisé :")
-    mail = input("📧 Mail (nom@domain.com) : ").strip()
-    alias = mail  #input("📛 Alias (visible) : ").strip()
-    server = input("🌐 Server : ").strip()
-    username = input("👤 Username (domain\\user) : ").strip()
-    password = input("🔑 Password (non masqué) : ").strip()
-    interval = int(input("⏱️ Interval (secondes) : ").strip())
-    if alias == "''" or alias == "\"\"" or alias == "":
-        alias = mail
-
-    if 0 != enregistrer_config_owa_secure(mail, alias, server, username, password, interval):
-        print("❌ Erreur lors de enregistrer_config_owa_secure !")
-
-
-def lecture_config_cli_owa_secure():
-    fichier = input("📄 Nom du fichier JSON (sans chemin) : ").strip()
-    cfg = lire_config_owa_secure(fichier)
-
-    if cfg is None:
-        print("❌ Erreur")
-        return
-
-    print(f"\n📧 mail        : {cfg[0]}")
-    print(f"📛 alias       : {cfg[1]}")
-    print(f"🌐 server      : {cfg[2]}")
-    print(f"👤 username    : {cfg[3]}")
-    print(f"🔑 password    : {cfg[4]}")
-    print(f"⏱️ intervalle  : {cfg[5]}s")
-
-
-def lire_config_owa_secure(chemin_fichier):
-    try:
-        chemin_fichier = os.path.join(get_keys_dir("MICROSOFT_EXCHANGE_OWA_SECURE"), chemin_fichier)
-        with open(chemin_fichier, "r", encoding="utf-8") as f:
-            contenu = json.load(f)
-
-        mdp_dechiffre = decrypt_secure(contenu["password_encrypted"])
-
-        return [
-            contenu["mail"],
-            contenu["alias"],
-            contenu["server"],
-            contenu["username"],
-            mdp_dechiffre,
-            int(contenu["interval_second"])
-        ]
-
-    except Exception as e:
-        print(f"❌ Erreur de lecture sécurisée OWA : {e}")
-        return None
-
 
 # Fonction pour lire le fichier de configuration et déchiffrer le mot de passe
 def lire_config_imap4_ssl(chemin_fichier):
@@ -317,6 +264,27 @@ def lire_config_oauth2(chemin_fichier):
 
 
 def lire_config_owa(chemin_fichier):
+    if len(chemin_fichier)<5:
+        print(f"❌ Error path not correct", chemin_fichier)
+        return None
+    if chemin_fichier.endswith(".sec"):
+        try:
+            service="MICROSOFT_EXCHANGE_OWA__"+chemin_fichier[:-4]
+            sm = secret_manager.SecretManager(service)
+            contenu=sm.load_all()
+            return [
+                contenu["mail"],
+                contenu["alias"],
+                contenu["server"],
+                contenu["username"],
+                contenu["password_encrypted"],
+                int(contenu["interval_second"])
+            ]
+
+        except Exception as e:
+            print(f"❌ Erreur lors de la lecture : {e}")
+            return None
+
     try:
         chemin_fichier = os.path.join(get_keys_dir("MICROSOFT_EXCHANGE_OWA"), chemin_fichier)
         print("chemin fichier", chemin_fichier)
@@ -362,10 +330,16 @@ def enregistrer_config_cli_owa():
     username = input("usernamme (domaine\\username): ").strip()
     mdp = input("password?: ").strip()
     interval = int(input("⏱️ Intervalle en secondes : ").strip())
+    store = ask_secure()
+
     if alias == "''" or alias == "\"\"" or alias == "":
         alias = mail
-
-    if 0 != enregistrer_config_owa(mail, alias, server, username, mdp, interval):
+    if not store:
+        print("not secure")
+        if 0 != enregistrer_config_owa(mail, alias, server, username, mdp, interval):
+            print("erreur!")
+        return
+    if 0 != enregistrer_config_owa_secure(mail, alias, server, username, mdp, interval):
         print("erreur!")
 
 
@@ -428,7 +402,7 @@ def lire_config_cli_oauth2():
 
 
 def lecture_config_cli_owa():
-    chemin_fichier = input("📄 non fichier json (pas le chemin!) JSON : ").strip()
+    chemin_fichier = input("📄 non fichier json (pas le chemin!) JSON ou sec : ").strip()
     config = lire_config_owa(chemin_fichier)
 
     if config == None:
@@ -611,6 +585,7 @@ def lire_config_cli_nxp():
 
 
 if __name__ == "__main__":
+    print("add --no-log-tigger")
     print("1) ecrire fichier IMAP4_SSL")
     print("2) dechiffer fichier IMAP4_SSL")
     print("3) Écrire fichier CLÉ API")
@@ -621,11 +596,10 @@ if __name__ == "__main__":
     print("8) Déchiffrer fichier Microsoft Exchange (OWA)")
     print("9) Écrire fichier Microsoft Exchange (OAuth2)")
     print("10) Déchiffrer fichier Microsoft Exchange (OAuth2)")
-    print("11) Écrire fichier Microsoft Exchange (OWA) [SECURE]")
-    print("12) Déchiffrer fichier Microsoft Exchange (OWA) [SECURE]")
-    print("14) ")
 
-    choix = input("👉 Que faire ? [1-14] : ").strip()
+
+
+    choix = input("👉 Que faire ? [1-10] : ").strip()
 
     if choix == "1":
         enregistrer_config_cli_imap4_ssl()
@@ -647,10 +621,7 @@ if __name__ == "__main__":
         enregistrer_config_cli_oauth2()
     elif choix == "10":
         lire_config_cli_oauth2()
-    elif choix == "11":
-        enregistrer_config_cli_owa_secure()
-    elif choix == "12":
-        lecture_config_cli_owa_secure()
+
 
 
     else:
